==> central-repository-3.59.0.zip: java/util/concurrent/RejectedExecutionException.java <==
/*
 * Copyright (C) 2016-2019 MicroEJ Corp. - EDC compliance and optimizations.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * This file is available under and governed by the GNU General Public
 * License version 2 only, as published by the Free Software Foundation.
 * However, the following notice accompanied the original version of this
 * file:
 *
 * Written by Doug Lea with assistance from members of JCP JSR-166
 * Expert Group and released to the public domain, as explained at
 * http://creativecommons.org/publicdomain/zero/1.0/
 */

package java.util.concurrent;

/**
 * Exception thrown by an {@link Executor} when a task cannot be accepted for execution.
 *
 * @since 1.5
 * @author Doug Lea
 */
public class RejectedExecutionException extends RuntimeException {
	private static final long serialVersionUID = -375805702767069545L;

	/**
	 * Constructs a {@code RejectedExecutionException} with no detail message. The cause is not initialized, and may
	 * subsequently be initialized by a call to {@link #initCause(Throwable) initCause}.
	 */
	public RejectedExecutionException() {
	}

	/**
	 * Constructs a {@code RejectedExecutionException} with the specified detail message. The cause is not initialized,
	 * and may subsequently be initialized by a call to {@link #initCause(Throwable) initCause}.
	 *
	 * @param message
	 *            the detail message
	 */
	public RejectedExecutionException(String message) {
		super(message);
	}

	/**
	 * Constructs a {@code RejectedExecutionException} with the specified detail message and cause.
	 *
	 * @param message
	 *            the detail message
	 * @param cause
	 *            the cause (which is saved for later retrieval by the {@link #getCause()} method)
	 */
	public RejectedExecutionException(String message, Throwable cause) {
		super(message, cause);
	}

	/**
	 * Constructs a {@code RejectedExecutionException} with the specified cause. The detail message is set to
	 * {@code (cause ==
	 * null ? null : cause.toString())} (which typically contains the class and detail message of {@code cause}).
	 *
	 * @param cause
	 *            the cause (which is saved for later retrieval by the {@link #getCause()} method)
	 */
	public RejectedExecutionException(Throwable cause) {
		super(cause);
	}
}

==> central-repository-3.63.0.zip: java/util/concurrent/RejectedExecutionException.java <==
/*
 * Copyright (C) 2016-2020 MicroEJ Corp. - EDC compliance and optimizations.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * This file is available under and governed by the GNU General Public
 * License version 2 only, as published by the Free Software Foundation.
 * However, the following notice accompanied the original version of this
 * file:
 *
 * Written by Doug Lea with assistance from members of JCP JSR-166
 * Expert Group and released to the public domain, as explained at
 * http://creativecommons.org/publicdomain/zero/1.0/
 */

package java.util.concurrent;

import ej.annotation.Nullable;

/**
 * Exception thrown by an {@link Executor} when a task cannot be accepted for execution.
 *
 * @since 1.5
 * @author Doug Lea
 */
public class RejectedExecutionException extends RuntimeException {
	private static final long serialVersionUID = -375805702767069545L;

	/**
	 * Constructs a {@code RejectedExecutionException} with no detail message. The cause is not initialized, and may
	 * subsequently be initialized by a call to {@link #initCause(Throwable) initCause}.
	 */
	public RejectedExecutionException() {
	}

	/**
	 * Constructs a {@code RejectedExecutionException} with the specified detail message. The cause is not initialized,
	 * and may subsequently be initialized by a call to {@link #initCause(Throwable) initCause}.
	 *
	 * @param message
	 *            the detail message
	 */
	public RejectedExecutionException(String message) {
		super(message);
	}

	/**
	 * Constructs a {@code RejectedExecutionException} with the specified detail message and cause.
	 *
	 * @param message
	 *            the detail message
	 * @param cause
	 *            the cause (which is saved for later retrieval by the {@link #getCause()} method)
	 */
	public RejectedExecutionException(String message, @Nullable Throwable cause) {
		super(message, cause);
	}

	/**
	 * Constructs a {@code RejectedExecutionException} with the specified cause. The detail message is set to
	 * {@code (cause ==
	 * null ? null : cause.toString())} (which typically contains the class and detail message of {@code cause}).
	 *
	 * @param cause
	 *            the cause (which is saved for later retrieval by the {@link #getCause()} method)
	 */
	public RejectedExecutionException(@Nullable Throwable cause) {
		super(cause);
	}
}
